==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/finders/IfFinder.h <==
// public class soot.dava.toolkits.base.finders.IfFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eba5259faceb7edf soot_dava_toolkits_base_finders_IfFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_IfFinder_H_
#define _JC_soot_dava_toolkits_base_finders_IfFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_IfFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_IfFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_IfFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$refs	_jc_soot_dava_toolkits_base_finders_IfFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_IfFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$object	_jc_soot_dava_toolkits_base_finders_IfFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_IfFinder$vmethods	_jc_soot_dava_toolkits_base_finders_IfFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_IfFinder$vtable	_jc_soot_dava_toolkits_base_finders_IfFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_IfFinder$vtype	_jc_soot_dava_toolkits_base_finders_IfFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_IfFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_IfFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_toolkits_base_finders_IfFinder$method$find__5fBody$d99132ad2ea1e369(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_IfFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_IfFinder$method_info$find__5fBody$d99132ad2ea1e369;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *_jc_soot_dava_toolkits_base_finders_IfFinder$method$v$fda0c7db5149bf71(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_IfFinder$vmethods {
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
	struct _jc_soot_util_IterableSet$object	*(*find__5fBody$d99132ad2ea1e369)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_IfFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_IfFinder$vmethods	soot_dava_toolkits_base_finders_IfFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_IfFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_IfFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_IfFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_IfFinder$refs {
    _jc_soot_dava_toolkits_base_finders_IfFinder$sub_refs	soot_dava_toolkits_base_finders_IfFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_IfFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_IfFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_IfFinder$sub_nonrefs	soot_dava_toolkits_base_finders_IfFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_IfFinder$object {
	_jc_soot_dava_toolkits_base_finders_IfFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_IfFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_IfFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_IfFinder$vtype _jc_soot_dava_toolkits_base_finders_IfFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_IfFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_IfFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_IfFinder_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/finders/IfFinder.h <==
// public class soot.dava.toolkits.base.finders.IfFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eba5259faceb7edf soot_dava_toolkits_base_finders_IfFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_IfFinder_H_
#define _JC_soot_dava_toolkits_base_finders_IfFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_IfFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_IfFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_IfFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$refs	_jc_soot_dava_toolkits_base_finders_IfFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_IfFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_IfFinder$object	_jc_soot_dava_toolkits_base_finders_IfFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_IfFinder$vmethods	_jc_soot_dava_toolkits_base_finders_IfFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_IfFinder$vtable	_jc_soot_dava_toolkits_base_finders_IfFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_IfFinder$vtype	_jc_soot_dava_toolkits_base_finders_IfFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_IfFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_IfFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_toolkits_base_finders_IfFinder$method$find__5fBody$d99132ad2ea1e369(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_IfFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_IfFinder$method_info$find__5fBody$d99132ad2ea1e369;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *_jc_soot_dava_toolkits_base_finders_IfFinder$method$v$fda0c7db5149bf71(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_IfFinder$vmethods {
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_IterableSet$object	*(*find__5fBody$d99132ad2ea1e369)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_IfFinder$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_IfFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_IfFinder$vmethods	soot_dava_toolkits_base_finders_IfFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_IfFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_IfFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_IfFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_IfFinder$refs {
    _jc_soot_dava_toolkits_base_finders_IfFinder$sub_refs	soot_dava_toolkits_base_finders_IfFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_IfFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_IfFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_IfFinder$sub_nonrefs	soot_dava_toolkits_base_finders_IfFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_IfFinder$object {
	_jc_soot_dava_toolkits_base_finders_IfFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_IfFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_IfFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_IfFinder$vtype _jc_soot_dava_toolkits_base_finders_IfFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_IfFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_IfFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_IfFinder_H_ */
